#!/usr/local/env python
#############################################################################
# Name:         check.py
# Purpose:      Simple test view for V7000 Unified Storage Appliance adapter
#               functionality
# Maintainer:   Torsten Kurbad
# Copyright:    (c) 2013 iwm-kmrc.de KMRC - Knowledge Media Research Center
# Licence:      GPL
#############################################################################
"""View Class for the Container's Contents view.

"""
from zope.app.pagetemplate.viewpagetemplatefile import ViewPageTemplateFile
from zope.publisher.browser import BrowserView

from v7000uadapter.interfaces import IManageV7000UAdapter
from v7000uadapter.interfaces import ICheckManageV7000UAdapter


class CheckManageV7000UAdapterView(BrowserView):

    __used_for__ = IManageV7000UAdapter

    def __init__(self, context, request):
        self.context = context
        self.request = request
        self.__parent__ = context
        self.report = []

    def getConnInfo(self):
        """ Returns a dict with configuration information. """
        infoDict = {}
        infoDict['hostName'] = self.context.hostName
        infoDict['adminUser'] = self.context.adminUser
        infoDict['profileExport'] = self.context.profileExport
        infoDict['profileMountpoint'] = self.context.profileMountpoint
        infoDict['sshKeyConfigured'] = (self.context.adminSSHKey is not None) and (self.context.adminSSHKey != u'')
        return infoDict


    def checkConnection(self):
        """ Check connection and execute some commands on the appliance. """
        if self.request.get('runDefault', None):
            testadapter = ICheckManageV7000UAdapter(self.context)
            self._addInfo(u'<strong>'
                          u'Test python connection to IBM Storwize V7000 Unified via SSH'
                          u'</strong>')
            self.report = self.report + testadapter.testConnection()
            self._addInfo(u' ')
            self._addInfo(u'<strong>Tests done</strong>')
            self._addInfo(u' ')
    
            return self.report
        else:
            return u''

    def _addInfo(self, res):
        """ Add traceback info to the report list. """
        self.report.append(res)

    check = ViewPageTemplateFile('check.pt')
