#!/usr/local/env python
#############################################################################
# Name:         interfaces.py
# Purpose:      Configure and Manage IBM V7000 Unified Storage Appliance
# Maintainer:   Torsten Kurbad
# Copyright:    (c) 2013 iwm-kmrc.de KMRC - Knowledge Media Research Center
# Licence:      GPL
#############################################################################
""" Adapter to V7000 Unified management module

"""

from zope.interface import Interface
from zope.schema import Bool, Password, Text, TextLine

from zope.i18nmessageid import MessageFactory
_ = MessageFactory('v7000uadapter')


class IManageV7000UAdapter(Interface):
    """ Make v7000u module persistent in ZODB. """

    hostName = TextLine(
        title=_(u'Host name'),
        description=_(u'The management hostname (or IP address) of the V7000 Unified appliance.'),
        required=True)
    
    sshHostKey = Text(
        title=_(u'SSH host key'),
        description=_(u'SSH RSA|DSS public host key of the V7000 Unified appliance (ssh-rsa ...|ssh-dss ...).'),
        required=True)

    adminUser = TextLine(
        title=_(u'User name'),
        description=_(u'Administrative user name of the V7000 Unified appliance.'),
        required=True)

    adminPassword = Password(
        title=_(u'Password (optional)'),
        description=_(u'Password of the administrative user.'),
        required=False)

    adminSSHKey = Text(
        title=_(u'SSH private key'),
        description=_(u'SSH RSA|DSS private key of administrative user.'),
        required=False)

    profileExport = TextLine(
        title=_(u'Profile export'),
        description=_(u"Export path of the profile share on the V7000 Unified appliance, as given by 'lsexport'."),
        required=True)

    profileMountpoint = TextLine(
        title=_(u'Local profile mount point'),
        description=_(u'Mount point of profile share on the local machine, i.e. the one running Zope.'),
        required=True)

    autoRegister = Bool(
        title=_(u'Autoregister'),
        description=_(u'Automatically register as V7000UAdapter utility.'),
        default=True,
        required=False)


class ICheckManageV7000UAdapter(Interface):
    """ Test v7000u adapter connectivity. """

    def testConnection():
        """ Return a list of connection results to display in TAL. """
